@@ -23,6 +23,8 @@
 #
 # \arguments{
 #  \item{x}{A @numeric NxK @matrix.}
+#  \item{rows, cols}{A @vector indicating subset of rows (and/or columns)
+#     to operate over. If @NULL, no subsetting is done.}
 #  \item{na.rm}{If @TRUE, @NAs are excluded first, otherwise not.}
 #  \item{dim.}{An @integer @vector of length two specifying the
 #              dimension of \code{x}, also when not a @matrix.}
@@ -50,46 +52,48 @@
 # @keyword robust
 # @keyword univar
 #*/###########################################################################
-rowRanges <- function(x, na.rm=FALSE, dim.=dim(x), ...) {
+rowRanges <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, dim.=dim(x), ...) {
   dim. <- as.integer(dim.)
   na.rm <- as.logical(na.rm)
-  .Call("rowRanges", x, dim., 2L, na.rm, TRUE, PACKAGE="matrixStats")
+  .Call("rowRanges", x, dim., rows, cols, 2L, na.rm, TRUE, PACKAGE="matrixStats")
 }
 
-rowMins <- function(x, na.rm=FALSE, dim.=dim(x), ...) {
+rowMins <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, dim.=dim(x), ...) {
   dim. <- as.integer(dim.)
   na.rm <- as.logical(na.rm)
-  .Call("rowRanges", x, dim., 0L, na.rm, TRUE, PACKAGE="matrixStats")
+  .Call("rowRanges", x, dim., rows, cols, 0L, na.rm, TRUE, PACKAGE="matrixStats")
 }
 
-rowMaxs <- function(x, na.rm=FALSE, dim.=dim(x), ...) {
+rowMaxs <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, dim.=dim(x), ...) {
   dim. <- as.integer(dim.)
   na.rm <- as.logical(na.rm)
-  .Call("rowRanges", x, dim., 1L, na.rm, TRUE, PACKAGE="matrixStats")
+  .Call("rowRanges", x, dim., rows, cols, 1L, na.rm, TRUE, PACKAGE="matrixStats")
 }
 
 
-colRanges <- function(x, na.rm=FALSE, dim.=dim(x), ...) {
+colRanges <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, dim.=dim(x), ...) {
   dim. <- as.integer(dim.)
   na.rm <- as.logical(na.rm)
-  .Call("colRanges", x, dim., 2L, na.rm, TRUE, PACKAGE="matrixStats")
+  .Call("colRanges", x, dim., rows, cols, 2L, na.rm, TRUE, PACKAGE="matrixStats")
 }
 
-colMins <- function(x, na.rm=FALSE, dim.=dim(x), ...) {
+colMins <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, dim.=dim(x), ...) {
   dim. <- as.integer(dim.)
   na.rm <- as.logical(na.rm)
-  .Call("colRanges", x, dim., 0L, na.rm, TRUE, PACKAGE="matrixStats")
+  .Call("colRanges", x, dim., rows, cols, 0L, na.rm, TRUE, PACKAGE="matrixStats")
 }
 
-colMaxs <- function(x, na.rm=FALSE, dim.=dim(x), ...) {
+colMaxs <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, dim.=dim(x), ...) {
   dim. <- as.integer(dim.)
   na.rm <- as.logical(na.rm)
-  .Call("colRanges", x, dim., 1L, na.rm, TRUE, PACKAGE="matrixStats")
+  .Call("colRanges", x, dim., rows, cols, 1L, na.rm, TRUE, PACKAGE="matrixStats")
 }
 
 
 ############################################################################
 # HISTORY:
+# 2015-05-25 [DJ]
+# o Supported subsetted computation.
 # 2014-12-17 [HB]
 # o CLEANUP: Made col- and rowRanges() plain R functions.
 # 2014-11-16
