@@ -21,6 +21,8 @@
 #   \item{w}{a vector of weights the same length as \code{x} giving the weights
 #            to use for each element of \code{x}. Negative weights are treated
 #            as zero weights. Default value is equal weight to all values.}
+#   \item{idxs, rows, cols}{A @vector indicating subset of elements (or rows and/or columns)
+#            to operate over. If @NULL, no subsetting is done.}
 #   \item{na.rm}{a logical value indicating whether @NA values in
 #            \code{x} should be stripped before the computation proceeds,
 #            or not.  If @NA, no check at all for @NAs is done.
@@ -53,7 +55,7 @@
 # @keyword "univar"
 # @keyword "robust"
 #*/############################################################################
-weightedMad <- function(x, w=NULL, na.rm=FALSE, constant=1.4826, center=NULL, ...) {
+weightedMad <- function(x, w=NULL, idxs=NULL, na.rm=FALSE, constant=1.4826, center=NULL, ...) {
   # No weights? Fall back to non-weighted method.
   if (is.null(w)) {
     if (is.null(center)) center <- median(x, na.rm=na.rm)
@@ -66,6 +68,15 @@ weightedMad <- function(x, w=NULL, na.rm=FALSE, constant=1.4826, center=NULL, ..
   # Argument 'w':
   if (length(w) != n) {
     stop("The number of elements in arguments 'w' and 'x' does not match: ", length(w), " != ", n);
+  } else if (!is.null(idxs)) {
+    # Apply subset on w
+    w <- w[idxs]
+  }
+
+  # Apply subset on x
+  if (!is.null(idxs)) {
+    x <- x[idxs]
+    n <- length(x)
   }
 
   # Argument 'na.rm':
@@ -137,11 +148,27 @@ weightedMad <- function(x, w=NULL, na.rm=FALSE, constant=1.4826, center=NULL, ..
 } # weightedMad()
 
 
-rowWeightedMads <- function(x, w=NULL, na.rm=FALSE, ...) {
+rowWeightedMads <- function(x, w=NULL, rows=NULL, cols=NULL, na.rm=FALSE, ...) {
+  # Apply subset on x
+  if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+  else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+  else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+
+  # Apply subset on w
+  if (!is.null(w) && !is.null(cols)) w <- w[cols]
+
   apply(x, MARGIN=1L, FUN=weightedMad, w=w, na.rm=na.rm, ...)
 } # rowWeightedMads()
 
-colWeightedMads <- function(x, w=NULL, na.rm=FALSE, ...) {
+colWeightedMads <- function(x, w=NULL, rows=NULL, cols=NULL, na.rm=FALSE, ...) {
+  # Apply subset on x
+  if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+  else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+  else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+
+  # Apply subset on w
+  if (!is.null(w) && !is.null(rows)) w <- w[rows]
+
   apply(x, MARGIN=2L, FUN=weightedMad, w=w, na.rm=na.rm, ...)
 } # colWeightedMads()
 
@@ -149,6 +176,8 @@ colWeightedMads <- function(x, w=NULL, na.rm=FALSE, ...) {
 
 ############################################################################
 # HISTORY:
+# 2015-05-31 [DJ]
+# o Supported subsetted computation.
 # 2014-11-10
 # o Turned weightedMad() into a plain function.
 # 2013-11-23
