@@ -1,10 +1,9 @@
 /***********************************************************************
  TEMPLATE:
-  void rowVars_<Integer|Real>(...)
+  void rowVars_<Integer|Real>(ARGUMENTS_LIST)
 
- GENERATES:
-  void rowVars_Integer(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int narm, int hasna, int byrow, double *ans)
-  void rowVars_Real(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int narm, int hasna, int byrow, double *ans)
+ ARGUMENTS_LIST:
+  X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, void *rows, R_xlen_t nrows, void *cols, R_xlen_t ncols, int narm, int hasna, int byrow, double *ans
 
  Arguments:
    The following macros ("arguments") should be defined for the
@@ -29,40 +28,45 @@
 #include "templates-types.h"
 
 
-void METHOD_NAME(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int narm, int hasna, int byrow, double *ans) {
-  R_xlen_t ii, jj, kk;
+RETURN_TYPE METHOD_NAME_ROWS_COLS(ARGUMENTS_LIST) {
+  R_xlen_t ii, jj, kk, idx;
   R_xlen_t *colOffset;
   X_C_TYPE *values, value;
   double value_d, mu_d, sigma2_d;
 
+#ifdef ROWS_TYPE
+  ROWS_C_TYPE *crows = (ROWS_C_TYPE*) rows;
+#endif
+#ifdef COLS_TYPE
+  COLS_C_TYPE *ccols = (COLS_C_TYPE*) cols;
+#endif
+
   /* R allocate memory for the 'values'.  This will be
      taken care of by the R garbage collector later on. */
-  values   = (X_C_TYPE *) R_alloc(ncol, sizeof(X_C_TYPE));
+  values = (X_C_TYPE *) R_alloc(ncols, sizeof(X_C_TYPE));
 
   /* If there are no missing values, don't try to remove them. */
   if (hasna == FALSE)
     narm = FALSE;
 
   /* Pre-calculate the column offsets */
-  colOffset = (R_xlen_t *) R_alloc(ncol, sizeof(R_xlen_t));
+  colOffset = (R_xlen_t *) R_alloc(ncols, sizeof(R_xlen_t));
 
   if (byrow) {
-    for (jj=0; jj < ncol; jj++)
-      colOffset[jj] = (R_xlen_t)jj*nrow;
+    for (jj=0; jj < ncols; jj++)
+      colOffset[jj] = R_INDEX_OP(COL_INDEX(ccols,jj), *, nrow);
   } else {
-    for (jj=0; jj < ncol; jj++)
-      colOffset[jj] = (R_xlen_t)jj;
+    for (jj=0; jj < ncols; jj++)
+      colOffset[jj] = COL_INDEX(ccols,jj);
   }
 
-  for (ii=0; ii < nrow; ii++) {
-    if (ii % 1000 == 0)
-      R_CheckUserInterrupt();
-
-    R_xlen_t rowIdx = byrow ? ii : ncol*ii; //HJ
+  for (ii=0; ii < nrows; ii++) {
+    R_xlen_t rowIdx = byrow ? ROW_INDEX(crows,ii) : R_INDEX_OP(ROW_INDEX(crows,ii), *, ncol); //HJ
 
     kk = 0;
-    for (jj=0; jj < ncol; jj++) {
-      value = x[rowIdx+colOffset[jj]];
+    for (jj=0; jj < ncols; jj++) {
+      idx = R_INDEX_OP(rowIdx, +, colOffset[jj]);
+      value = R_INDEX_GET(x, idx, X_NA); //HJ
 
       if (X_ISNAN(value)) {
         if (narm == FALSE) {
@@ -91,22 +95,23 @@ void METHOD_NAME(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int narm, int hasna,
       sigma2_d = 0;
       for (jj=0; jj < kk; jj++) {
         value_d = ((double)values[jj] - mu_d);
-	value_d *= value_d;
+        value_d *= value_d;
         sigma2_d += value_d;
       }
       sigma2_d /= (double)(kk-1);
 
       ans[ii] = sigma2_d;
     } /* if (kk <= 1) */
+
+    R_CHECK_USER_INTERRUPT(ii);
   } /* for (ii ...) */
 }
 
-/* Undo template macros */
-#include "templates-types_undef.h"
-
 
 /***************************************************************************
  HISTORY:
+ 2015-06-13 [DJ]
+  o Supported subsetted computation.
  2014-11-18 [HB]
   o Created from rowMads_TYPE-template.h.
  **************************************************************************/
