@@ -26,7 +26,7 @@ indexByRow_R2 <- function(dim, idxs=NULL, ...) {
 dim <- c(5L, 4L)
 X <- matrix(NA_integer_, nrow=dim[1L], ncol=dim[2L])
 Y <- t(X)
-idxsByCols <- seq(along=X)
+idxsByCols <- seq_along(X)
 
 # Assign by columns
 X[idxsByCols] <- idxsByCols
@@ -62,3 +62,10 @@ stopifnot(all(idxs_R1 == idxsByRows))
 
 idxs_R2 <- indexByRow_R2(dim, idxs=idxsByCols)
 stopifnot(all(idxs_R2 == idxsByRows))
+
+
+## DEPRECATED: Backward compatibility
+idxs0 <- indexByRow(dim)
+idxs1 <- indexByRow(X)
+stopifnot(identical(idxs1, idxs0))
+
